import { Component, forwardRef, Injector, Input, NgModule, Renderer2, HostListener, ChangeDetectorRef, Inject, ViewContainerRef } from '@angular/core';
import { TranslateModule, TranslateService } from '@ngx-translate/core';
import { NarikAutoComplete, NARIK_DATA_DISPLAY_VALUE_INPUTS, NARIK_DATA_DISPLAY_VALUE_OUTPUTS, NarikButton, BUTTON_DEFAULT_OPTIONS, NarikCheckBox, NARIK_CHECKBOX_INPUTS, NarikCheckBoxList, NarikDataTable, NarikDatePicker, NARIK_DATE_PICKER_INPUTS, NarikInput, NARIK_INPUT_INPUTS, NarikRadioGroup, NarikSelect, NARIK_SELECT_INPUTS, NarikDynamicForm, NarikTreeview, NarikToolBar } from 'narik-ui-core';
import { NG_VALUE_ACCESSOR, FormsModule } from '@angular/forms';
import { map } from 'rxjs/internal/operators/map';
import { debounceTime } from 'rxjs/internal/operators/debounceTime';
import { distinctUntilChanged } from 'rxjs/internal/operators/distinctUntilChanged';
import { switchMap } from 'rxjs/internal/operators/switchMap';
import { tap } from 'rxjs/internal/operators/tap';
import { finalize } from 'rxjs/internal/operators/finalize';
import { of } from 'rxjs/internal/observable/of';
import { DataProviderService, MODULE_DATA_KEY, DIALOG_CONTAINER, DIALOG_MESSAGE_COMPONENT, DIALOG_INPUT_COMPONENT } from 'narik-infrastructure';
import { NgbTypeaheadModule, NgbTooltipModule, NgbDatepickerModule, NgbDateAdapter, NgbDateNativeAdapter } from '@ng-bootstrap/ng-bootstrap';
import { CommonModule, DOCUMENT } from '@angular/common';
import { BusyIndicator, NarikListForm, NarikDetailForm } from 'narik-app-core';
import { __decorate, __metadata } from 'tslib';
import { NarikInject, NarikDialogContainer, DialogAnimationBody } from 'narik-core';
import { groupBy, NarikCommonModule } from 'narik-common';
import { FlexLayoutModule } from '@angular/flex-layout';
import { trigger } from '@angular/animations';
import { UUID } from 'angular2-uuid';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbAutoComplete extends NarikAutoComplete {
    /**
     * @param {?} injector
     */
    constructor(injector) {
        super(injector);
        this.internalChange = false;
        this.optionData = [];
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set displayValue(value) {
        if (this._displayValue !== value) {
            if (!this.internalChange) {
                this.setValue(value);
            }
            this._displayValue = value;
        }
    }
    /**
     * @return {?}
     */
    get displayValue() {
        return this._displayValue;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.loadDataOnInit = !this.isLazyLoadData;
        super.ngOnInit();
        if (!this.isLazyLoadData) {
            this.search = (/**
             * @param {?} text$
             * @return {?}
             */
            (text$) => text$.pipe(debounceTime(200), distinctUntilChanged(), map((/**
             * @param {?} term
             * @return {?}
             */
            (term) => term.length < this.minSearchLength
                ? []
                : this.optionData
                    .filter((/**
                 * @param {?} v
                 * @return {?}
                 */
                v => this.displayField
                    ? v[this.displayField]
                    : v.toLowerCase().indexOf(term.toLowerCase()) > -1))
                    .map((/**
                 * @param {?} v
                 * @return {?}
                 */
                v => (this.displayField ? v[this.displayField] : v)))
                    .slice(0, 10)))));
        }
        else {
            /** @type {?} */
            const dataProviderService = this.injector.get(DataProviderService);
            /** @type {?} */
            const dataInfo = this.createDataInfo();
            dataInfo.dataMethod = "POST";
            dataInfo.actionType = "COMPLETE";
            if (!dataInfo.moduleKey) {
                dataInfo.moduleKey = this.injector.get(MODULE_DATA_KEY);
            }
            this.search = (/**
             * @param {?} text$
             * @return {?}
             */
            (text$) => text$.pipe(debounceTime(200), distinctUntilChanged(), tap((/**
             * @param {?} filter
             * @return {?}
             */
            filter => {
                if (filter && filter.length >= this.minSearchLength) {
                    this.dataIsLoading = true;
                }
            })), switchMap((/**
             * @param {?} filter
             * @return {?}
             */
            filter => {
                dataInfo.dataParameters = {
                    filter: filter
                };
                return filter && filter.length >= this.minSearchLength
                    ? dataProviderService.getData(dataInfo).pipe(tap((/**
                     * @param {?} result
                     * @return {?}
                     */
                    (result) => (this.optionData = result))), finalize((/**
                     * @return {?}
                     */
                    () => (this.dataIsLoading = false))))
                    : of([]);
            }))));
        }
    }
    /**
     * @param {?} selectedText
     * @return {?}
     */
    setValue(selectedText) {
        this.internalChange = true;
        if (!this.displayField) {
            this.value = selectedText;
        }
        else {
            if (selectedText) {
                /** @type {?} */
                const item = this.optionData.filter((/**
                 * @param {?} x
                 * @return {?}
                 */
                x => x[this.displayField] === selectedText))[0];
                if (item) {
                    this.value = item[this.valueField];
                }
                else {
                    this.value = undefined;
                }
            }
            else {
                this.value = undefined;
            }
        }
        this.internalChange = false;
    }
    /**
     * @protected
     * @param {?} data
     * @return {?}
     */
    useData(data) {
        this.optionData = data;
    }
    /**
     * @return {?}
     */
    setDisplayText() {
        this.internalChange = true;
        if (this.value) {
            /** @type {?} */
            const item = this.optionData.filter((/**
             * @param {?} x
             * @return {?}
             */
            x => x[this.valueField] === this.value))[0];
            this.displayValue = item ? item[this.displayField] : this.displayText;
        }
        else {
            this.displayValue = "";
        }
        this.internalChange = false;
    }
    /**
     * @protected
     * @param {?} newValue
     * @param {?} oldValue
     * @return {?}
     */
    valueChanged(newValue, oldValue) {
        if (newValue !== oldValue && !this.internalChange) {
            this.setDisplayText();
        }
    }
    /**
     * @return {?}
     */
    onBlur() {
        if (!this.isLazyLoadData) {
            this.setDisplayText();
        }
    }
}
NarikNgbAutoComplete.decorators = [
    { type: Component, args: [{
                selector: "narik-ngb-autocomplete  , narik-autocomplete ",
                template: "<div class=\"form-group\">\r\n  <label for=\"{{id}}\">{{label}}</label>\r\n  <div class=\"input-group mb-3\" *ngIf=\"icon\">\r\n    <div class=\"input-group-prepend\">\r\n      <span class=\"input-group-text\"><i class=\"fa fa-{{icon}}\"></i></span>\r\n    </div>\r\n    <ng-container *ngTemplateOutlet=\"inputElement\"></ng-container>\r\n  </div>\r\n  <ng-container *ngIf=\"!icon\">\r\n    <ng-container *ngTemplateOutlet=\"inputElement\"></ng-container>\r\n  </ng-container>\r\n\r\n</div>\r\n<ng-template #inputElement>\r\n  <input (blur)=\"onBlur()\" [required]=\"required\" [(ngModel)]=\"displayValue\" [attr.disabled]=\"disabled || null\"\r\n    type=\"text\" name=\"{{name}}\" class=\"form-control\" [ngbTypeahead]=\"search\" id=\"{{id}}\" placeholder=\"{{placeHolder}}\">\r\n  <input type=\"hidden\" name=\"{{name}}\" [(ngModel)]=\"value\">\r\n</ng-template>",
                inputs: [...NARIK_DATA_DISPLAY_VALUE_INPUTS],
                outputs: [...NARIK_DATA_DISPLAY_VALUE_OUTPUTS],
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => NarikNgbAutoComplete)),
                        multi: true
                    }
                ],
                styles: [""]
            }] }
];
/** @nocollapse */
NarikNgbAutoComplete.ctorParameters = () => [
    { type: Injector }
];
NarikNgbAutoComplete.propDecorators = {
    icon: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbAutoCompleteModule {
}
NarikNgbAutoCompleteModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, FormsModule, NgbTypeaheadModule],
                declarations: [NarikNgbAutoComplete],
                exports: [NarikNgbAutoComplete],
                providers: []
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbBusyIndicator {
    /**
     * @param {?} newState
     * @param {?=} msg
     * @return {?}
     */
    setBusy(newState, msg) {
        this.isBusy = newState;
    }
}
NarikNgbBusyIndicator.decorators = [
    { type: Component, args: [{
                selector: "narik-ngb-busy-indicator , narik-busy-indicator",
                template: "<ng-content></ng-content>\r\n<div class=\"loading-panel\" *ngIf=\"isBusy\"></div>\r\n<div *ngIf=\"isBusy\" id=\"loader-wrapper\">\r\n  <div class=\"spinner-border text-primary\" role=\"status\">\r\n    <span class=\"sr-only\">Loading...</span>\r\n  </div>\r\n</div>\r\n",
                providers: [
                    {
                        provide: BusyIndicator,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => NarikNgbBusyIndicator))
                    }
                ],
                styles: [".loading-panel{width:100%;position:absolute;top:0;left:0;bottom:0;right:0;background-color:#fff;opacity:.4;z-index:50000}#loader-wrapper{width:64px;height:64px;position:absolute;left:50%;top:50%;z-index:1000;margin-left:-20px;margin-top:-20px}"]
            }] }
];
NarikNgbBusyIndicator.propDecorators = {
    isBusy: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbBusyIndicatorModule {
}
NarikNgbBusyIndicatorModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, TranslateModule],
                declarations: [NarikNgbBusyIndicator],
                exports: [NarikNgbBusyIndicator],
                providers: []
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbButtonComponent extends NarikButton {
    /**
     * @param {?} renderer
     * @param {?} injector
     */
    constructor(renderer, injector) {
        super(injector);
        this.renderer = renderer;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onClick(event) {
        event.stopPropagation();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        super.ngOnInit();
        this.buttonStyle = this.buttonStyle || this.defaultOptions.buttonStyle;
        this.busyFontIcon = this.busyFontIcon || this.defaultOptions.busyFontIcon;
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() { }
    /**
     * @param {?} e
     * @return {?}
     */
    buttonClick(e) {
        if (!this.disable && !this.isBusy) {
            this.nClick.emit({
                sender: this,
                event: e
            });
        }
    }
}
NarikNgbButtonComponent.decorators = [
    { type: Component, args: [{
                selector: "narik-ngb-button , narik-button ",
                template: "<button ngbTooltip=\"{{tooltip}}\" placement=\"bottom\" (click)=\"buttonClick($event)\" [disabled]=\"disable || isBusy\" class=\"btn btn-{{buttonStyle}}\" type=\"button\"\r\n[ngClass]='cssClass'>\r\n  <span *ngIf=\"isBusy\" class=\"mx-1 spinner-border spinner-border-sm\" role=\"status\" aria-hidden=\"true\"></span>\r\n  <i *ngIf=\"icon\" class=\"fa fa-{{icon}}\"></i>\r\n  {{ isBusy && busyLabel ? busyLabel : label}}\r\n</button>\r\n"
            }] }
];
/** @nocollapse */
NarikNgbButtonComponent.ctorParameters = () => [
    { type: Renderer2 },
    { type: Injector }
];
NarikNgbButtonComponent.propDecorators = {
    onClick: [{ type: HostListener, args: ["click", ["$event"],] }]
};
__decorate([
    NarikInject(BUTTON_DEFAULT_OPTIONS, {
        buttonStyle: "secondary",
        busyFontIcon: "fa-spinner"
    }),
    __metadata("design:type", Object)
], NarikNgbButtonComponent.prototype, "defaultOptions", void 0);

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbButtonModule {
}
NarikNgbButtonModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, NgbTooltipModule],
                declarations: [NarikNgbButtonComponent],
                exports: [NarikNgbButtonComponent],
                providers: []
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbCheckBox extends NarikCheckBox {
    /**
     * @param {?} injector
     */
    constructor(injector) {
        super(injector);
    }
}
NarikNgbCheckBox.decorators = [
    { type: Component, args: [{
                selector: "narik-ngb-checkbox , narik-checkbox",
                template: "<div class=\"form-check\">\r\n  <input [attr.disabled]=\"disabled || null\" class=\"form-check-input\" type=\"checkbox\"\r\n  [(ngModel)]=\"value\" id=\"{{id}}\">\r\n  <label class=\"form-check-label\" for=\"{{id}}\">\r\n    {{label}}\r\n  </label>\r\n</div>\r\n",
                inputs: [...NARIK_CHECKBOX_INPUTS],
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => NarikNgbCheckBox)),
                        multi: true
                    },
                    {
                        provide: NarikCheckBox,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => NarikNgbCheckBox))
                    }
                ]
            }] }
];
/** @nocollapse */
NarikNgbCheckBox.ctorParameters = () => [
    { type: Injector }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbCheckBoxModule {
}
NarikNgbCheckBoxModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, FormsModule],
                declarations: [NarikNgbCheckBox],
                exports: [NarikNgbCheckBox],
                providers: []
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbCheckBoxList extends NarikCheckBoxList {
    /**
     * @param {?} injector
     */
    constructor(injector) {
        super(injector);
        this.itemsData = [];
        this._layoutDirection = "vertical";
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set layoutDirection(value) {
        this._layoutDirection = value;
    }
    /**
     * @return {?}
     */
    get layoutDirection() {
        return this._layoutDirection;
    }
    /**
     * @protected
     * @param {?} data
     * @return {?}
     */
    useData(data) {
        this.itemsData = data;
    }
}
NarikNgbCheckBoxList.decorators = [
    { type: Component, args: [{
                selector: "narik-ngb-checkbox-list , narik-checkbox-list",
                template: "<div class=\"form-group\">\r\n  <label for=\"{{id}}\">{{label}}</label>\r\n  <div class=\"form-check-container p-1 pl-2\">\r\n    <div [ngClass]=\"{ 'vertical-content': layoutDirection == 'vertical' }\">\r\n      <narik-checkbox *ngFor=\"let item of itemsData\" (Change)=\"addOrRemove(valueField ? item[valueField] : item)\"\r\n        [tag]=\"valueField ? item[valueField] : item\" label=\"{{ item[displayField] }}\">\r\n      </narik-checkbox>\r\n    </div>\r\n  </div>\r\n</div>\r\n",
                inputs: [...NARIK_DATA_DISPLAY_VALUE_INPUTS],
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => NarikNgbCheckBoxList)),
                        multi: true
                    }
                ],
                styles: [".form-check-container{border:1px solid #ced4da;border-radius:.25rem}"]
            }] }
];
/** @nocollapse */
NarikNgbCheckBoxList.ctorParameters = () => [
    { type: Injector }
];
NarikNgbCheckBoxList.propDecorators = {
    layoutDirection: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbCheckBoxListModule {
}
NarikNgbCheckBoxListModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    FormsModule,
                    NarikNgbCheckBoxModule
                ],
                declarations: [NarikNgbCheckBoxList],
                exports: [NarikNgbCheckBoxList],
                providers: []
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbDataTable extends NarikDataTable {
    /**
     * @param {?} injector
     * @param {?} changeDetector
     * @param {?} document
     */
    constructor(injector, changeDetector, document) {
        super(injector);
        this.changeDetector = changeDetector;
        this.document = document;
    }
}
NarikNgbDataTable.decorators = [
    { type: Component, args: [{
                selector: "narik-ngb-data-table , narik-data-table",
                template: ""
            }] }
];
/** @nocollapse */
NarikNgbDataTable.ctorParameters = () => [
    { type: Injector },
    { type: ChangeDetectorRef },
    { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbDataTableModule {
}
NarikNgbDataTableModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, FormsModule, TranslateModule],
                declarations: [NarikNgbDataTable],
                exports: [NarikNgbDataTable],
                providers: []
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbDatePicker extends NarikDatePicker {
    /**
     * @param {?} injector
     */
    constructor(injector) {
        super(injector);
    }
}
NarikNgbDatePicker.decorators = [
    { type: Component, args: [{
                selector: "narik-ngb-date-picker , narik-date-picker",
                template: "<div class=\"form-group\">\r\n  <label for=\"{{id}}\">{{label}}</label>\r\n\r\n  <div class=\"input-group\">\r\n    <input [required]=\"required\" [attr.disabled]=\"disabled || null\" class=\"form-control\" id=\"{{id}}\" placeholder=\"{{placeHolder}}\" name=\"dp\"\r\n      [(ngModel)]=\"value\" ngbDatepicker #d=\"ngbDatepicker\">\r\n    <div class=\"input-group-append\">\r\n      <button class=\"btn btn-outline-secondary\" (click)=\"d.toggle()\" type=\"button\">\r\n        <i class=\"fa fa-calendar-alt\" aria-hidden=\"true\"></i>\r\n      </button>\r\n    </div>\r\n  </div>\r\n\r\n</div>\r\n",
                inputs: [...NARIK_DATE_PICKER_INPUTS],
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => NarikNgbDatePicker)),
                        multi: true
                    }
                ]
            }] }
];
/** @nocollapse */
NarikNgbDatePicker.ctorParameters = () => [
    { type: Injector }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbDatePickerModule {
}
NarikNgbDatePickerModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, FormsModule, NgbDatepickerModule, TranslateModule],
                declarations: [NarikNgbDatePicker],
                exports: [NarikNgbDatePicker],
                providers: [{ provide: NgbDateAdapter, useClass: NgbDateNativeAdapter }]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbInput extends NarikInput {
    /**
     * @param {?} injector
     */
    constructor(injector) {
        super(injector);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set icon(value) {
        this._icon = value;
    }
    /**
     * @return {?}
     */
    get icon() {
        return this._icon;
    }
}
NarikNgbInput.decorators = [
    { type: Component, args: [{
                selector: "narik-ngb-input , narik-input",
                template: "<div class=\"form-group \">\r\n  <label for=\"{{id}}\">{{label}}</label>\r\n  <div class=\"input-group mb-3\" *ngIf=\"icon\">\r\n    <div class=\"input-group-prepend\">\r\n      <span class=\"input-group-text\"><i class=\"fa fa-{{icon}}\"></i></span>\r\n    </div>\r\n    <ng-container *ngTemplateOutlet=\"inputElement\"></ng-container>\r\n  </div>\r\n  <ng-container *ngIf=\"!icon\">\r\n    <ng-container *ngTemplateOutlet=\"inputElement\"></ng-container>\r\n  </ng-container>\r\n\r\n</div>\r\n<ng-template #inputElement>\r\n  <input [(ngModel)]=\"value\" [attr.disabled]=\"disabled || null\" type=\"{{type}}\" name=\"{{name}}\" [required]=\"required\"\r\n    class=\"form-control\" id=\"{{id}}\" placeholder=\"{{placeHolder}}\">\r\n</ng-template>",
                inputs: [...NARIK_INPUT_INPUTS],
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => NarikNgbInput)),
                        multi: true
                    }
                ]
            }] }
];
/** @nocollapse */
NarikNgbInput.ctorParameters = () => [
    { type: Injector }
];
NarikNgbInput.propDecorators = {
    icon: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbInputModule {
}
NarikNgbInputModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, FormsModule],
                declarations: [NarikNgbInput],
                exports: [NarikNgbInput],
                providers: []
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbRadioGroup extends NarikRadioGroup {
    /**
     * @param {?} injector
     */
    constructor(injector) {
        super(injector);
        this.itemsData = [];
        this._layoutDirection = "vertical";
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set layoutDirection(value) {
        this._layoutDirection = value;
    }
    /**
     * @return {?}
     */
    get layoutDirection() {
        return this._layoutDirection;
    }
    /**
     * @protected
     * @param {?} data
     * @return {?}
     */
    useData(data) {
        this.itemsData = data;
    }
}
NarikNgbRadioGroup.decorators = [
    { type: Component, args: [{
                selector: "narik-ngb-radio-group , narik-radio-group",
                template: "<div class=\"form-group\">\r\n  <label for=\"{{id}}\">{{label}}</label>\r\n  <div class=\"form-check-container p-1 pl-2\">\r\n    <div class=\"form-check \" [ngClass]=\"{'form-check-inline': layoutDirection==='horizontal'}\"\r\n      *ngFor=\"let item of itemsData;let i=index\">\r\n      <input [required]=\"required\" [attr.disabled]=\"disabled || null\" class=\"form-check-input\" type=\"radio\" name=\"{{name}}\" id=\"{{id+i}}\"\r\n        value=\"{{item[valueField]}}\" checked>\r\n      <label class=\"form-check-label\" for=\"{{id+i}}\">\r\n        {{item[displayField]}}\r\n      </label>\r\n    </div>\r\n  </div>\r\n</div>\r\n",
                inputs: [...NARIK_DATA_DISPLAY_VALUE_INPUTS],
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => NarikNgbRadioGroup)),
                        multi: true
                    }
                ],
                styles: [".form-check-container{border:1px solid #ced4da;border-radius:.25rem}"]
            }] }
];
/** @nocollapse */
NarikNgbRadioGroup.ctorParameters = () => [
    { type: Injector }
];
NarikNgbRadioGroup.propDecorators = {
    layoutDirection: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbRadioGroupModule {
}
NarikNgbRadioGroupModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, FormsModule],
                declarations: [NarikNgbRadioGroup],
                exports: [NarikNgbRadioGroup],
                providers: []
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbSelect extends NarikSelect {
    /**
     * @param {?} injector
     */
    constructor(injector) {
        super(injector);
        this.optionData = [];
    }
    /**
     * @protected
     * @param {?} data
     * @return {?}
     */
    useData(data) {
        this.optionData = data;
    }
}
NarikNgbSelect.decorators = [
    { type: Component, args: [{
                selector: "narik-ngb-select , narik-select",
                template: "<div class=\"form-group\">\r\n  <label for=\"{{id}}\">{{label}}</label>\r\n  <div class=\"input-group mb-3\" *ngIf=\"icon\">\r\n    <div class=\"input-group-prepend\">\r\n      <span class=\"input-group-text\"><i class=\"fa fa-{{icon}}\"></i></span>\r\n    </div>\r\n    <ng-container *ngTemplateOutlet=\"inputElement\"></ng-container>\r\n  </div>\r\n  <ng-container *ngIf=\"!icon\">\r\n    <ng-container *ngTemplateOutlet=\"inputElement\"></ng-container>\r\n  </ng-container>\r\n\r\n</div>\r\n<ng-template #inputElement>\r\n\r\n  <select [required]=\"required\" class=\"custom-select\" [(ngModel)]=\"value\" [attr.disabled]=\"disabled || null\"\r\n    id=\"{{id}}\">\r\n    <option *ngFor=\"let item of optionData\" [value]=\"item[valueField]\">{{item[displayField]}}</option>\r\n  </select>\r\n\r\n\r\n\r\n</ng-template>",
                inputs: [...NARIK_DATA_DISPLAY_VALUE_INPUTS, ...NARIK_SELECT_INPUTS],
                outputs: [...NARIK_DATA_DISPLAY_VALUE_OUTPUTS],
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => NarikNgbSelect)),
                        multi: true
                    }
                ],
                styles: [".select-clear{position:absolute;left:-2px;top:-30px}.search-input{padding:16px;box-sizing:border-box}.search-continer{border-bottom:1px solid rgba(0,0,0,.12);top:0;width:100%;position:-webkit-sticky;position:sticky;background-color:#fff;z-index:10000}"]
            }] }
];
/** @nocollapse */
NarikNgbSelect.ctorParameters = () => [
    { type: Injector }
];
NarikNgbSelect.propDecorators = {
    icon: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbSelectModule {
}
NarikNgbSelectModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, FormsModule],
                declarations: [NarikNgbSelect],
                exports: [NarikNgbSelect],
                providers: []
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbDynamicForm extends NarikDynamicForm {
    /**
     * @param {?} injector
     * @param {?} viewContainerRef
     */
    constructor(injector, viewContainerRef) {
        super(injector, viewContainerRef);
        this.columnWidth = 100;
        this.fieldsArray = new Map();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        super.ngOnInit();
        if (this.columnsCount === 1) {
            this.layoutGap = 0;
        }
        if (this.groupFields) {
            /** @type {?} */
            const data = groupBy(this.fields, "options.groupIndex");
            data.forEach((/**
             * @param {?} x
             * @return {?}
             */
            x => this.fieldsArray.set(x.key && x.key !== "undefined" ? +x.key : 0, x.value)));
            this.groupCount =
                Math.max(...this.fieldsArray.entriesArray().map((/**
                 * @param {?} x
                 * @return {?}
                 */
                x => x.key))) + 1;
        }
        this.columnWidth = 100 / this.columnsCount;
    }
}
NarikNgbDynamicForm.decorators = [
    { type: Component, args: [{
                selector: "narik-dynamic-form , narik-ngb-dynamic-form",
                template: "<div [tab-guard]=\"activeTabGuard\" [auto-focus]=\"activeAutoFocus\" [autoFocusContainerName]=\"defaultFocusField\"\r\n  fxLayout=\"{{columnsCount === 1 ? 'column' : 'row wrap'}} \" fxLayout.xs=\"column\" fxLayoutGap.xs=\"0\"\r\n  fxLayoutGap=\"{{ layoutGap }}px\" fxLayoutAlign=\"flex-start\">\r\n  <ng-container *ngIf=\"!groupFields\">\r\n    <div fxFlex.lt-sm=\"100%\" fxFlex.lt-xl=\"0 1 calc({{ columnWidth }}% - {{ layoutGap }}px)\"\r\n      fxFlex.lt-md=\"0 1 calc({{ columnWidth }}% - {{ layoutGap }}px)\" *ngFor=\"let item of fields; let i = index\">\r\n      <ng-container *ngTemplateOutlet=\"\r\n          fieldContainer;\r\n          context: {\r\n            $implicit: item,\r\n            invisibleItems: invisibleItems,\r\n            disableItems: disableItems,\r\n            model: model\r\n          }\r\n        \"></ng-container>\r\n    </div>\r\n  </ng-container>\r\n  <ng-container *ngIf=\"groupFields\">\r\n    <div fxFlex.lt-sm=\"100%\" fxFlex.lt-xl=\"0 1 calc({{ columnWidth }}% - {{ layoutGap }}px)\"\r\n      fxFlex.lt-md=\"0 1 calc({{ columnWidth }}% - {{ layoutGap }}px)\"\r\n      *ngFor=\"let item of [].constructor(groupCount); let i = index\">\r\n      <div fxLayout=\"column\" class=\"narik-form-group\">\r\n        <div *ngFor=\"let item of fieldsArray.get(i); let j = index\">\r\n          <ng-container *ngTemplateOutlet=\"\r\n              fieldContainer;\r\n              context: {\r\n                $implicit: item,\r\n                invisibleItems: invisibleItems,\r\n                disableItems: disableItems,\r\n                model: model\r\n              }\r\n            \"></ng-container>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </ng-container>\r\n</div>\r\n\r\n<ng-template #fieldContainer let-item let-invisibleItems=\"invisibleItems\" let-model=\"model\"\r\n  let-disableItems=\"disableItems\">\r\n  <ng-container *ngIf=\"!item.hideExpr || !invisibleItems[item.name]\">\r\n    <ng-container *ngIf=\"\r\n        !item.type ||\r\n        item.type == 'text' ||\r\n        item.type == 'number' ||\r\n        item.type == 'time' ||\r\n        item.type == 'textArea' ||\r\n        item.type == 'password'\r\n      \">\r\n      <narik-input [name]=\"item.name\" [disabled]=\"item.disableExpr && disableItems[item.name]\"\r\n        [required]=\"item.required\" placeHolder=\"{{ item.options.placeHolder | translate }}\" [type]=\"item.type || 'text'\"\r\n        label=\"{{ item.label | translate }}\" [(ngModel)]=\"model[item.model]\" [options]=\"item.options\"\r\n        [narikValidator]=\"item.validators\" [narikValidatorParams]=\"item.validatorParams\">\r\n      </narik-input>\r\n    </ng-container>\r\n    <ng-container *ngIf=\"item.type == 'boolean'\">\r\n      <narik-checkbox [name]=\"item.name\" [disabled]=\"item.disableExpr && disableItems[item.name]\"\r\n        [options]=\"item.options\" [(ngModel)]=\"model[item.model]\" label=\"{{ item.label | translate }}\"\r\n        [narikValidator]=\"item.validators\" [narikValidatorParams]=\"item.validatorParams\">\r\n      </narik-checkbox>\r\n    </ng-container>\r\n    <ng-container *ngIf=\"item.type == 'date'\">\r\n      <narik-date-picker [options]=\"item.options\" [disabled]=\"item.disableExpr && disableItems[item.name]\"\r\n        [name]=\"item.name\" [required]=\"item.required\" placeHolder=\"{{ item.options.placeHolder | translate }}\"\r\n        [(ngModel)]=\"model[item.model]\" label=\"{{ item.label | translate }}\" [narikValidator]=\"item.validators\"\r\n        [narikValidatorParams]=\"item.validatorParams\"></narik-date-picker>\r\n    </ng-container>\r\n    <ng-container *ngIf=\"item.type == 'select'\">\r\n      <narik-select [options]=\"item.options\" [name]=\"item.name\" [disabled]=\"item.disableExpr && disableItems[item.name]\"\r\n        [required]=\"item.required\" placeHolder=\"{{ item.options.placeHolder | translate }}\" [dataInfo]=\"item.dataInfo\"\r\n        label=\"{{ item.label | translate }}\" [(ngModel)]=\"model[item.model]\" [narikValidator]=\"item.validators\"\r\n        [narikValidatorParams]=\"item.validatorParams\"></narik-select>\r\n    </ng-container>\r\n    <ng-container *ngIf=\"item.type == 'autoComplete'\">\r\n      <narik-autocomplete [options]=\"item.options\" [name]=\"item.name\"\r\n        [disabled]=\"item.disableExpr && disableItems[item.name]\" [required]=\"item.required\"\r\n        placeHolder=\"{{ item.options.placeHolder | translate }}\" [minSearchLength]=\"item.options.minSearchLength || 0\"\r\n        [isLazyLoadData]=\"item.options.isLazyLoadData\" [dataInfo]=\"item.dataInfo\" label=\"{{ item.label | translate }}\"\r\n        [(ngModel)]=\"model[item.model]\" [narikValidator]=\"item.validators\"\r\n        [narikValidatorParams]=\"item.validatorParams\"></narik-autocomplete>\r\n    </ng-container>\r\n    <ng-container *ngIf=\"item.type == 'radio'\">\r\n      <narik-radio-group [options]=\"item.options\" [name]=\"item.name\"\r\n        [disabled]=\"item.disableExpr && disableItems[item.name]\" [required]=\"item.required\"\r\n        placeHolder=\"{{ item.options.placeHolder | translate }}\" [dataInfo]=\"item.dataInfo\"\r\n        label=\"{{ item.label | translate }}\" [(ngModel)]=\"model[item.model]\" [narikValidator]=\"item.validators\"\r\n        [narikValidatorParams]=\"item.validatorParams\"></narik-radio-group>\r\n    </ng-container>\r\n    <ng-container *ngIf=\"item.type == 'checkList'\">\r\n      <narik-checkbox-list [options]=\"item.options\" [name]=\"item.name\"\r\n        [disabled]=\"item.disableExpr && disableItems[item.name]\" [required]=\"item.required\"\r\n        placeHolder=\"{{ item.options.placeHolder | translate }}\" [dataInfo]=\"item.dataInfo\"\r\n        label=\"{{ item.label | translate }}\" [(ngModel)]=\"model[item.model]\" [narikValidator]=\"item.validators\"\r\n        [narikValidatorParams]=\"item.validatorParams\"></narik-checkbox-list>\r\n    </ng-container>\r\n    <ng-container *ngIf=\"item.type == 'table-select'\">\r\n\r\n    </ng-container>\r\n  </ng-container>\r\n</ng-template>",
                providers: [
                    {
                        provide: NarikDynamicForm,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => NarikNgbDynamicForm))
                    }
                ]
            }] }
];
/** @nocollapse */
NarikNgbDynamicForm.ctorParameters = () => [
    { type: Injector },
    { type: ViewContainerRef }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbDynamicFormModule {
}
NarikNgbDynamicFormModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    FormsModule,
                    TranslateModule,
                    NarikNgbInputModule,
                    NarikNgbSelectModule,
                    NarikNgbCheckBoxModule,
                    NarikNgbRadioGroupModule,
                    NarikNgbAutoCompleteModule,
                    NarikNgbDatePickerModule,
                    NarikNgbCheckBoxListModule,
                    NarikCommonModule,
                    FlexLayoutModule
                ],
                declarations: [NarikNgbDynamicForm],
                exports: [NarikNgbDynamicForm],
                providers: []
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbDialogContainer extends NarikDialogContainer {
    /**
     * @return {?}
     */
    ngOnInit() { }
}
NarikNgbDialogContainer.decorators = [
    { type: Component, args: [{
                template: "<div [@openClose]=\"isOpen ? 'open' : 'closed'\" (@openClose.done)=\"_onAnimationDone($event)\" class=\"modal-content\"\r\n  cdkDrag [tab-guard]=\"true\">\r\n  <div class=\"modal-header\">\r\n    <h5 cdkDragHandle class=\"modal-title\">{{ title | translate }}</h5>\r\n  </div>\r\n\r\n  <div class=\"modal-body\">\r\n    <ng-template narik-loader-host></ng-template>\r\n  </div>\r\n\r\n  <div class=\"modal-footer\" [auto-focus]=\"true\" [autoFocusContainerName]=\"options.defaultAction\"\r\n    *ngIf=\"actions && actions.length!==0\" align=\"end\">\r\n    <ng-container *ngFor=\"let item of actions\">\r\n      <ng-container>\r\n        <narik-button cssClass=\"btn-sm\" [attr.narik-form-item-key]=\"item.dialogResult\" class=\"mr-2\"\r\n          (nClick)=\"actionClick(item)\" [color]=\"item.color\" [icon]=\"item.icon\"\r\n          label=\"{{'dialog-buttons.'+item.label | translate}}\"></narik-button>\r\n      </ng-container>\r\n    </ng-container>\r\n  </div>\r\n</div>",
                animations: [trigger("openClose", DialogAnimationBody)],
                styles: [".dialog-container{background-color:#fff;border-radius:5px;box-shadow:20px 20px 15px -7px rgba(0,0,0,.2),0 24px 38px 3px rgba(0,0,0,.14),0 9px 46px 8px rgba(0,0,0,.12)}"]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbInputDialog {
    constructor() {
        this.entity = {};
        this.fields = [];
    }
    /**
     * @return {?}
     */
    ngOnInit() { }
}
NarikNgbInputDialog.decorators = [
    { type: Component, args: [{
                template: "<div class=\"pr-2 pl-2\">\r\n  <narik-dynamic-form [model]=\"entity\" [fields]=\"fields\"></narik-dynamic-form>\r\n</div>\r\n"
            }] }
];
/** @nocollapse */
NarikNgbInputDialog.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbMessageDialog {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() { }
}
NarikNgbMessageDialog.decorators = [
    { type: Component, args: [{
                template: "<div class=\"message-container\">{{message | translate}}</div>\r\n",
                styles: [""]
            }] }
];
/** @nocollapse */
NarikNgbMessageDialog.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
const ɵ0 = NarikNgbDialogContainer, ɵ1 = NarikNgbMessageDialog, ɵ2 = NarikNgbInputDialog;
class NarikNgbDialogModule {
}
NarikNgbDialogModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    FormsModule,
                    TranslateModule,
                    NarikCommonModule,
                    NarikNgbButtonModule,
                    NarikNgbDynamicFormModule
                ],
                declarations: [
                    NarikNgbDialogContainer,
                    NarikNgbInputDialog,
                    NarikNgbMessageDialog
                ],
                exports: [
                    NarikNgbDialogContainer,
                    NarikNgbInputDialog,
                    NarikNgbMessageDialog
                ],
                providers: [
                    {
                        provide: DIALOG_CONTAINER,
                        useValue: ɵ0
                    },
                    {
                        provide: DIALOG_MESSAGE_COMPONENT,
                        useValue: ɵ1
                    },
                    {
                        provide: DIALOG_INPUT_COMPONENT,
                        useValue: ɵ2
                    }
                ],
                entryComponents: [
                    NarikNgbDialogContainer,
                    NarikNgbInputDialog,
                    NarikNgbMessageDialog
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbTreeview extends NarikTreeview {
    /**
     * @param {?} injector
     */
    constructor(injector) {
        super(injector);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set selectedItem(value) {
        this._selectedItem = value;
    }
    /**
     * @return {?}
     */
    get selectedItem() {
        return this._selectedItem;
    }
    /**
     * @param {?} selectedNode
     * @return {?}
     */
    addNode(selectedNode) {
        throw new Error("Method not implemented.");
    }
    /**
     * @param {?} selectedNode
     * @return {?}
     */
    deleteNode(selectedNode) {
        throw new Error("Method not implemented.");
    }
}
NarikNgbTreeview.decorators = [
    { type: Component, args: [{
                selector: "narik-ngb-treeview narik-treeview",
                template: ""
            }] }
];
/** @nocollapse */
NarikNgbTreeview.ctorParameters = () => [
    { type: Injector }
];
NarikNgbTreeview.propDecorators = {
    newNodeTitle: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbToolBar extends NarikToolBar {
    /**
     * @param {?} injector
     * @param {?} viewContainerRef
     */
    constructor(injector, viewContainerRef) {
        super(injector, viewContainerRef);
        this.uniqueId = "";
        this.toolbarItems = [];
        this.uniqueId = "toolbar" + UUID.UUID();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        super.ngOnInit();
        /** @type {?} */
        let isnewGroup = false;
        /** @type {?} */
        let toolBarGroup = [];
        for (const item of this.items) {
            if (item.itemType === "divider") {
                isnewGroup = true;
            }
            if (item.itemType !== "divider") {
                toolBarGroup.push(item);
            }
            if (isnewGroup) {
                this.toolbarItems.push([...toolBarGroup]);
                toolBarGroup = [];
            }
            isnewGroup = false;
        }
        if (toolBarGroup.length !== 0) {
            this.toolbarItems.push(toolBarGroup);
        }
        for (const group of this.toolbarItems) {
            /** @type {?} */
            let index = 0;
            for (const item of group) {
                /** @type {?} */
                let cssClass = "";
                if (index !== 0) {
                    cssClass += " btn-not-first-child";
                }
                if (index !== group.length - 1) {
                    cssClass += " btn-not-last-child";
                }
                item.cssClass = (item.cssClass || "") + cssClass;
                index++;
            }
        }
    }
}
NarikNgbToolBar.decorators = [
    { type: Component, args: [{
                selector: "narik-toolbar , narik-ngb-toolbar",
                template: "<div class=\"btn-toolbar\"  role=\"toolbar\" aria-label=\"Toolbar with button groups\">\r\n  <div class=\"btn-group mr-1\" *ngFor=\"let group of toolbarItems\" role=\"group\" aria-label=\"First group\">\r\n    <ng-container *ngFor='let item of group;let i=index'>\r\n      <ng-container *ngIf=\"item.itemType==='button'\">\r\n        <narik-button class=\"toolbar-btn\" *ngIf='!item.hideExpr || !invisibleItems[item.key]'\r\n          [disable]=\"item.disableExpr && disableItems[item.key]\" [isBusy]=\"item.busyExpr && busyItems[item.key]\"\r\n          [cssClass]=\"item.cssClass\"\r\n          (nClick)=\"itemCommand(item)\" [buttonStyle]='\"secondary\"' [icon]=\"item.icon\"\r\n          tooltip=\"{{ item.hint | translate}}\"\r\n          [label]=\"showLabel ? item.label : ''\"></narik-button>\r\n      </ng-container>\r\n    </ng-container>\r\n  </div>\r\n</div>\r\n"
            }] }
];
/** @nocollapse */
NarikNgbToolBar.ctorParameters = () => [
    { type: Injector },
    { type: ViewContainerRef }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbToolbarModule {
}
NarikNgbToolbarModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    FormsModule,
                    NarikNgbButtonModule,
                    TranslateModule
                ],
                declarations: [NarikNgbToolBar],
                exports: [NarikNgbToolBar],
                providers: []
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbTreeviewModule {
}
NarikNgbTreeviewModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    FormsModule,
                    NarikNgbToolbarModule,
                    TranslateModule
                ],
                declarations: [NarikNgbTreeview],
                exports: [NarikNgbTreeview],
                providers: []
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbCoreModule {
}
NarikNgbCoreModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [],
                exports: [],
                providers: []
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikUiNgBootstrapModule {
}
NarikUiNgBootstrapModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    TranslateModule,
                    NarikNgbAutoCompleteModule,
                    NarikNgbBusyIndicatorModule,
                    NarikNgbButtonModule,
                    NarikNgbCheckBoxModule,
                    NarikNgbCheckBoxListModule,
                    NarikNgbDataTableModule,
                    NarikNgbDatePickerModule,
                    NarikNgbDialogModule,
                    NarikNgbDynamicFormModule,
                    NarikNgbInputModule,
                    NarikNgbRadioGroupModule,
                    NarikNgbSelectModule,
                    NarikNgbToolbarModule,
                    NarikNgbTreeviewModule,
                    NarikNgbCoreModule
                ],
                declarations: [],
                exports: [
                    TranslateModule,
                    NarikNgbAutoCompleteModule,
                    NarikNgbBusyIndicatorModule,
                    NarikNgbButtonModule,
                    NarikNgbCheckBoxModule,
                    NarikNgbCheckBoxListModule,
                    NarikNgbDataTableModule,
                    NarikNgbDatePickerModule,
                    NarikNgbDialogModule,
                    NarikNgbDynamicFormModule,
                    NarikNgbInputModule,
                    NarikNgbRadioGroupModule,
                    NarikNgbSelectModule,
                    NarikNgbToolbarModule,
                    NarikNgbTreeviewModule,
                    NarikNgbCoreModule
                ],
                providers: []
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @template T
 */
class NarikUiListForm extends NarikListForm {
    /**
     * @param {?} injector
     */
    constructor(injector) {
        super(injector);
        this.ds = [];
        this.hasDataSource = false;
    }
    /**
     * @return {?}
     */
    get isServerSide() {
        return this.config && this.config.isServerSideData ? true : false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        super.ngOnInit();
        if (this.fields) ;
        if (this.config) {
            if (this.isServerSide) ;
        }
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() { }
    /**
     * @param {?} result
     * @return {?}
     */
    useData(result) {
        this.dataSource = (/** @type {?} */ (result.data));
    }
    /**
     * @protected
     * @param {?=} remoteDaraParams
     * @return {?}
     */
    refresh(remoteDaraParams) {
        if (!this.isServerSide) {
            this.getEntities();
        }
    }
}
__decorate([
    NarikInject(TranslateService),
    __metadata("design:type", TranslateService)
], NarikUiListForm.prototype, "translateService", void 0);

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @template T
 */
class NarikUiDetailForm extends NarikDetailForm {
    /**
     * @param {?} injector
     */
    constructor(injector) {
        super(injector);
    }
    /**
     * @return {?}
     */
    submit() {
        if (this.formElement) {
            this.renderer.addClass(this.formElement.nativeElement, "was-validated");
        }
        super.submit();
    }
}
__decorate([
    NarikInject(Renderer2),
    __metadata("design:type", Renderer2)
], NarikUiDetailForm.prototype, "renderer", void 0);

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { NarikNgbAutoComplete, NarikNgbAutoCompleteModule, NarikNgbBusyIndicator, NarikNgbBusyIndicatorModule, NarikNgbButtonComponent, NarikNgbButtonModule, NarikNgbCheckBox, NarikNgbCheckBoxList, NarikNgbCheckBoxListModule, NarikNgbCheckBoxModule, NarikNgbCoreModule, NarikNgbDataTable, NarikNgbDataTableModule, NarikNgbDatePicker, NarikNgbDatePickerModule, NarikNgbDialogContainer, NarikNgbDialogModule, NarikNgbDynamicForm, NarikNgbDynamicFormModule, NarikNgbInput, NarikNgbInputDialog, NarikNgbInputModule, NarikNgbMessageDialog, NarikNgbRadioGroup, NarikNgbRadioGroupModule, NarikNgbSelect, NarikNgbSelectModule, NarikNgbToolBar, NarikNgbToolbarModule, NarikNgbTreeview, NarikNgbTreeviewModule, NarikUiDetailForm, NarikUiListForm, NarikUiNgBootstrapModule };
//# sourceMappingURL=narik-ui-ng-bootstrap.js.map
